// src/hooks/useCrossmint.tsx
import { createContext, useCallback, useContext, useMemo, useRef, useState } from "react";
import { createCrossmint } from "@crossmint/common-sdk-base";
import { jsx } from "react/jsx-runtime";
var CrossmintContext = createContext(null);
function CrossmintProvider({
  children,
  apiKey,
  overrideBaseUrl
}) {
  const [version, setVersion] = useState(0);
  const crossmintRef = useRef(
    new Proxy(createCrossmint({ apiKey, overrideBaseUrl }), {
      set(target, prop, value2) {
        if (prop === "jwt" && target.jwt !== value2) {
          setVersion((v) => v + 1);
        }
        return Reflect.set(target, prop, value2);
      }
    })
  );
  const setJwt = useCallback((jwt) => {
    if (jwt !== crossmintRef.current.jwt) {
      crossmintRef.current.jwt = jwt;
    }
  }, []);
  const value = useMemo(
    () => ({
      get crossmint() {
        return crossmintRef.current;
      },
      setJwt
    }),
    [setJwt, version]
  );
  return /* @__PURE__ */ jsx(CrossmintContext.Provider, { value, children });
}
function useCrossmint(missingContextMessage) {
  const context = useContext(CrossmintContext);
  if (context == null) {
    throw new Error(missingContextMessage != null ? missingContextMessage : "useCrossmint must be used within a CrossmintProvider");
  }
  return context;
}

export {
  CrossmintProvider,
  useCrossmint
};
//# sourceMappingURL=chunk-3J6CUUWT.js.map