import {
  CrossmintEmbeddedCheckoutIFrame
} from "./chunk-C2VARNXL.js";
import {
  useDeepEffect
} from "./chunk-EOWJ7775.js";
import {
  __async,
  __spreadValues
} from "./chunk-CRTRMMJ7.js";

// src/components/embed/crypto/CryptoEmbeddedCheckoutIFrame.tsx
import bs58 from "bs58";
import {
  IncomingInternalEvents,
  OutgoingInternalEvents,
  crossmintIFrameService,
  embeddedCheckoutPropsToUpdatableParamsPayload
} from "@crossmint/client-sdk-base";
import { jsx } from "react/jsx-runtime";
function CryptoEmbeddedCheckoutIFrame(props) {
  const { emitInternalEvent } = crossmintIFrameService(props);
  const { signer, paymentMethod } = props;
  function onInternalEvent(event) {
    const { type, payload } = event;
    if (type === IncomingInternalEvents.CRYPTO_PAYMENT_INCOMING_TRANSACTION) {
      const { serializedTransaction } = payload;
      console.log("[Crossmint] Received incoming transaction", serializedTransaction);
      handleIncomingTransaction(serializedTransaction);
    }
    if (type === IncomingInternalEvents.CRYPTO_CHAIN_SWITCH) {
      const { chain } = payload;
      console.log("[Crossmint] Received change of chain", chain);
      const handleChainSwitch = signer.handleChainSwitch;
      if (handleChainSwitch == null) {
        throw new Error("switchNetwork function should have been defined");
      }
      handleChainSwitch(chain);
    }
  }
  function handleIncomingTransaction(serializedTransaction) {
    return __async(this, null, function* () {
      try {
        let txId;
        switch (paymentMethod) {
          case "SOL":
            txId = yield handleSOLTransaction(signer, serializedTransaction);
            break;
          case "ETH":
            txId = yield handleETHTransaction(signer, serializedTransaction);
            break;
          default:
            throw new Error(`Unsupported payment method ${paymentMethod}`);
        }
        console.log("[Crossmint] Signed and sent transaction", txId);
        emitInternalEvent({
          type: OutgoingInternalEvents.CRYPTO_PAYMENT_USER_ACCEPTED,
          payload: {
            txId
          }
        });
      } catch (e) {
        console.error("[Crossmint] Failed to sign and send transaction", e);
        emitInternalEvent({
          type: OutgoingInternalEvents.CRYPTO_PAYMENT_USER_REJECTED,
          payload: {}
        });
      }
    });
  }
  function handleSOLTransaction(signer2, serializedTransaction) {
    return __async(this, null, function* () {
      const { Transaction } = yield import("@solana/web3.js");
      const transaction = Transaction.from(bs58.decode(serializedTransaction));
      console.log("[Crossmint] Deserialized SOL transaction", transaction);
      return yield signer2.signAndSendTransaction(transaction);
    });
  }
  function handleETHTransaction(signer2, serializedTransaction) {
    return __async(this, null, function* () {
      const { parse: parseTransaction } = yield import("@ethersproject/transactions");
      const transaction = parseTransaction(serializedTransaction);
      console.log("[Crossmint] Deserialized ETH transaction", transaction);
      return yield signer2.signAndSendTransaction(transaction);
    });
  }
  useDeepEffect(() => {
    emitInternalEvent({
      type: "params-update",
      payload: embeddedCheckoutPropsToUpdatableParamsPayload(props)
    });
  }, [
    props.signer.address,
    props.recipient,
    props.mintConfig,
    props.locale,
    props.currency,
    props.whPassThroughArgs,
    ..."chain" in props.signer ? [props.signer.chain] : []
  ]);
  return /* @__PURE__ */ jsx(CrossmintEmbeddedCheckoutIFrame, __spreadValues({ onInternalEvent }, props));
}

export {
  CryptoEmbeddedCheckoutIFrame
};
//# sourceMappingURL=chunk-PHCGCJSA.js.map