import {
  __async,
  __spreadProps,
  __spreadValues
} from "./chunk-CRTRMMJ7.js";

// src/hooks/useDynamicConnect.ts
import { isEthereumWallet } from "@dynamic-labs/ethereum";
import { useDynamicContext } from "@dynamic-labs/sdk-react-core";
import { isSolanaWallet } from "@dynamic-labs/solana";
import { useCallback, useEffect } from "react";
function useDynamicConnect(isWeb3Enabled, setIsDynamicSdkLoaded, accessToken) {
  const {
    primaryWallet: connectedDynamicWallet,
    sdkHasLoaded,
    removeWallet,
    handleUnlinkWallet
  } = useDynamicContext();
  const dynamicSdkHasLoaded = !isWeb3Enabled || sdkHasLoaded;
  useEffect(() => {
    if (isWeb3Enabled) {
      setIsDynamicSdkLoaded(dynamicSdkHasLoaded);
    }
  }, [dynamicSdkHasLoaded, isWeb3Enabled]);
  const getAdminSigner = () => __async(this, null, function* () {
    if (!connectedDynamicWallet) {
      return null;
    }
    try {
      if (isEthereumWallet(connectedDynamicWallet)) {
        const dynamicClient = yield connectedDynamicWallet.getWalletClient();
        return __spreadProps(__spreadValues({}, dynamicClient), {
          address: dynamicClient.account.address,
          signer: {
            type: "viem_v2",
            account: __spreadProps(__spreadValues({}, dynamicClient.account), {
              signMessage: (data) => __async(this, null, function* () {
                return yield dynamicClient.signMessage({
                  message: data.message
                });
              })
            })
          },
          type: "evm-keypair"
        });
      }
      if (isSolanaWallet(connectedDynamicWallet)) {
        const signer = yield connectedDynamicWallet.getSigner();
        return __spreadProps(__spreadValues({}, signer), {
          address: connectedDynamicWallet.address,
          signer: __spreadValues({}, signer),
          type: "solana-keypair"
        });
      }
      return null;
    } catch (error) {
      console.error("Failed to get admin signer", error);
      return null;
    }
  });
  const cleanup = useCallback(() => {
    if (!accessToken && connectedDynamicWallet) {
      removeWallet(connectedDynamicWallet.id);
      handleUnlinkWallet(connectedDynamicWallet.id);
    }
  }, [accessToken, connectedDynamicWallet, removeWallet, handleUnlinkWallet]);
  return {
    sdkHasLoaded: dynamicSdkHasLoaded,
    getAdminSigner,
    cleanup,
    isDynamicWalletConnected: !!connectedDynamicWallet
  };
}

export {
  useDynamicConnect
};
//# sourceMappingURL=chunk-STNIRPZP.js.map