import {
  EmailSignersDialog
} from "./chunk-35QBUT6F.js";
import {
  FarcasterProvider
} from "./chunk-A7J4DAE7.js";
import {
  dynamicChainToCrossmintChain
} from "./chunk-7HENIDX5.js";
import {
  DynamicContextProviderWrapper
} from "./chunk-F2AWZC4M.js";
import {
  PasskeyPrompt
} from "./chunk-5OGRPJ2L.js";
import {
  CountdownButton
} from "./chunk-6TFIQWYJ.js";
import {
  Dialog,
  DialogContent,
  DialogDescription,
  DialogTitle
} from "./chunk-72LSMHPL.js";
import {
  InputOTP,
  InputOTPGroup,
  InputOTPSlot
} from "./chunk-33WZFL2D.js";
import {
  SecuredByCrossmint
} from "./chunk-5BYCXTC3.js";
import {
  Spinner
} from "./chunk-QTL5I5C2.js";
import {
  classNames
} from "./chunk-RZPQIRIY.js";
import {
  createWebAuthnPasskeySigner
} from "./chunk-FKL462NZ.js";
import {
  deriveWalletErrorState
} from "./chunk-V7CWLETC.js";
import {
  mapSignerToWalletType
} from "./chunk-OZKGMYKX.js";
import {
  TwindProvider
} from "./chunk-XSXE5LWO.js";
import {
  GoogleIcon
} from "./chunk-TKFSXTH5.js";
import {
  LeftArrowIcon
} from "./chunk-ZDQGQY7Z.js";
import {
  TwitterIcon
} from "./chunk-5TH75X5L.js";
import {
  WalletIcon
} from "./chunk-VZIXXIU5.js";
import {
  useSignerIFrameWindow
} from "./chunk-RB34BJZ6.js";
import {
  AlertIcon
} from "./chunk-7KIY6DLW.js";
import {
  ChevronRightIcon
} from "./chunk-3KR4GYLF.js";
import {
  EmailOtpIcon
} from "./chunk-I63FQCIV.js";
import {
  FarcasterIcon
} from "./chunk-ZIHCLVCD.js";
import {
  useCrossmint
} from "./chunk-3J6CUUWT.js";
import {
  useDynamicConnect
} from "./chunk-STNIRPZP.js";
import {
  __async,
  __objRest,
  __spreadProps,
  __spreadValues
} from "./chunk-CRTRMMJ7.js";

// src/providers/signers/CrossmintSignerProvider.tsx
import {
  createContext as createContext4,
  useContext as useContext5,
  useRef as useRef3,
  useState as useState9,
  useEffect as useEffect6,
  useMemo as useMemo4
} from "react";
import { CrossmintWallets as CrossmintWallets2 } from "@crossmint/wallets-sdk";
import { PublicKey } from "@solana/web3.js";
import base582 from "bs58";

// src/hooks/useWallet.ts
import { useContext } from "react";

// src/providers/CrossmintWalletProvider.tsx
import { createContext, useMemo, useState } from "react";
import { createPortal } from "react-dom";
import { CrossmintWallets } from "@crossmint/wallets-sdk";
import { jsx, jsxs } from "react/jsx-runtime";
var WalletContext = createContext({
  status: "not-loaded",
  getOrCreateWallet: () => Promise.resolve({ startedCreation: false }),
  createPasskeySigner: () => Promise.resolve(null),
  clearWallet: () => {
  }
});
function CrossmintWalletProvider({
  children,
  showPasskeyHelpers = true,
  appearance,
  experimental_enableRecoveryKeys = false
}) {
  const [walletState, setWalletState] = useState({
    status: "not-loaded"
  });
  const walletProviderProps = {
    walletState,
    setWalletState,
    showPasskeyHelpers,
    appearance,
    experimental_enableRecoveryKeys
  };
  return experimental_enableRecoveryKeys ? /* @__PURE__ */ jsx(TwindProvider, { children: /* @__PURE__ */ jsx(CrossmintSignerProvider, { walletState, setWalletState, appearance, children: /* @__PURE__ */ jsx(WalletProvider, __spreadProps(__spreadValues({}, walletProviderProps), { children })) }) }) : /* @__PURE__ */ jsx(WalletProvider, __spreadProps(__spreadValues({}, walletProviderProps), { children }));
}
function WalletProvider({
  children,
  showPasskeyHelpers = true,
  appearance,
  walletState,
  setWalletState,
  experimental_enableRecoveryKeys
}) {
  const { crossmint } = useCrossmint("CrossmintWalletProvider must be used within CrossmintProvider");
  const { experimental_getOrCreateWalletWithRecoveryKey } = useCrossmintSigner({
    enabled: experimental_enableRecoveryKeys != null ? experimental_enableRecoveryKeys : false
  });
  const smartWalletSDK = useMemo(
    () => CrossmintWallets.from({ apiKey: crossmint.apiKey, jwt: crossmint == null ? void 0 : crossmint.jwt }),
    [crossmint.apiKey, crossmint.jwt]
  );
  const [passkeyPromptState, setPasskeyPromptState] = useState({ open: false });
  const getOrCreateWallet = (props) => __async(this, null, function* () {
    var _a, _b;
    if (walletState.status == "in-progress") {
      return {
        startedCreation: false,
        reason: "Wallet is already loading."
      };
    }
    if (crossmint.jwt == null) {
      return {
        startedCreation: false,
        reason: `Jwt not set in "CrossmintProvider".`
      };
    }
    try {
      setWalletState({ status: "in-progress" });
      const passkeyPromptCallbacks = {
        onWalletCreationStart: createPasskeyPrompt("create-wallet"),
        onWalletCreationFail: createPasskeyPrompt("create-wallet-error"),
        onTransactionStart: createPasskeyPrompt("transaction"),
        onTransactionFail: createPasskeyPrompt("transaction-error")
      };
      switch (props.type) {
        case "evm-smart-wallet": {
          const walletArgs = {
            adminSigner: (_a = props.args.adminSigner) != null ? _a : { type: "evm-passkey" },
            linkedUser: props.args.linkedUser
          };
          const wallet = yield smartWalletSDK.getOrCreateWallet("evm-smart-wallet", walletArgs, {
            experimental_callbacks: ((_b = walletArgs.adminSigner) == null ? void 0 : _b.type) === "evm-passkey" ? passkeyPromptCallbacks : void 0
          });
          setWalletState({ status: "loaded", wallet, type: "evm-smart-wallet" });
          break;
        }
        case "solana-smart-wallet": {
          const wallet = yield smartWalletSDK.getOrCreateWallet("solana-smart-wallet", props.args);
          setWalletState({ status: "loaded", wallet, type: "solana-smart-wallet" });
          break;
        }
      }
    } catch (error) {
      console.error("There was an error creating a wallet ", error);
      setWalletState(deriveWalletErrorState(error));
    }
    return { startedCreation: true };
  });
  const createPasskeyPrompt = (type) => () => new Promise((resolve) => {
    if (!showPasskeyHelpers) {
      resolve();
      return;
    }
    setPasskeyPromptState({
      type,
      open: true,
      primaryActionOnClick: () => {
        setPasskeyPromptState({ open: false });
        resolve();
      },
      secondaryActionOnClick: () => {
        setPasskeyPromptState({ open: false });
        resolve();
      }
    });
  });
  const clearWallet = () => {
    setWalletState({ status: "not-loaded" });
  };
  const createPasskeySigner = (name, promptType) => __async(this, null, function* () {
    if (promptType != null) {
      yield createPasskeyPrompt(promptType)();
    }
    return yield createWebAuthnPasskeySigner(name);
  });
  const contextValue = useMemo(
    () => __spreadProps(__spreadValues({}, walletState), {
      getOrCreateWallet,
      createPasskeySigner,
      clearWallet,
      experimental_getOrCreateWalletWithRecoveryKey
    }),
    [walletState, experimental_getOrCreateWalletWithRecoveryKey]
  );
  return /* @__PURE__ */ jsxs(WalletContext.Provider, { value: contextValue, children: [
    children,
    passkeyPromptState.open ? createPortal(/* @__PURE__ */ jsx(PasskeyPrompt, { state: passkeyPromptState, appearance }), document.body) : null
  ] });
}

// src/hooks/useWallet.ts
function useWallet() {
  const walletContext = useContext(WalletContext);
  if (!walletContext) {
    throw new Error("useWallet must be used within CrossmintAuthProvider or CrossmintWalletProvider");
  }
  return walletContext;
}

// src/hooks/useAuth.ts
import { useContext as useContext4 } from "react";

// src/providers/CrossmintAuthProvider.tsx
import {
  createContext as createContext3,
  useEffect as useEffect5,
  useMemo as useMemo3,
  useRef as useRef2,
  useState as useState8,
  useCallback as useCallback2
} from "react";
import { CrossmintAuth, getCookie } from "@crossmint/client-sdk-auth";
import { validateApiKeyAndGetCrossmintBaseUrl } from "@crossmint/common-sdk-base";
import { SESSION_PREFIX } from "@crossmint/common-sdk-auth";

// src/components/auth/AuthFormDialog.tsx
import { VisuallyHidden } from "@radix-ui/react-visually-hidden";

// src/providers/auth/AuthFormProvider.tsx
import { createContext as createContext2, useCallback, useContext as useContext3, useEffect, useState as useState2 } from "react";
import { CrossmintAuthenticationError } from "@crossmint/common-sdk-auth";

// src/hooks/useCrossmintAuth.ts
import { useContext as useContext2 } from "react";
function useCrossmintAuth() {
  const context = useContext2(AuthContext);
  if (!context) {
    throw new Error("useCrossmintAuth must be used within a CrossmintAuthProvider");
  }
  return context;
}

// src/providers/auth/AuthFormProvider.tsx
import { jsx as jsx2 } from "react/jsx-runtime";
var initialOAuthUrlMap = {
  google: "",
  twitter: ""
  // Farcaster is not included here as it uses a different authentication method
};
var AuthFormContext = createContext2(void 0);
var useAuthForm = () => {
  const context = useContext3(AuthFormContext);
  if (!context) {
    throw new Error("useAuthForm must be used within an AuthFormProvider");
  }
  return context;
};
var AuthFormProvider = ({
  setDialogOpen,
  preFetchOAuthUrls,
  initialState,
  children
}) => {
  const { crossmintAuth } = useCrossmintAuth();
  const [step, setStep] = useState2("initial");
  const [error, setError] = useState2(null);
  const [oauthUrlMap, setOauthUrlMap] = useState2(initialOAuthUrlMap);
  const [isLoadingOauthUrlMap, setIsLoadingOauthUrlMap] = useState2(true);
  const { loginMethods, baseUrl, appearance, termsOfServiceText, authModalTitle, defaultEmail } = initialState;
  const preFetchAndSetOauthUrl = useCallback(() => __async(void 0, null, function* () {
    setIsLoadingOauthUrlMap(true);
    try {
      const oauthProviders = loginMethods.filter(
        (method) => method in initialOAuthUrlMap
      );
      const oauthPromiseList = oauthProviders.map((provider) => __async(void 0, null, function* () {
        const url = yield crossmintAuth == null ? void 0 : crossmintAuth.getOAuthUrl(provider);
        return { [provider]: url };
      }));
      const oauthUrlMap2 = Object.assign({}, ...yield Promise.all(oauthPromiseList));
      setOauthUrlMap(oauthUrlMap2);
    } catch (error2) {
      setError(
        error2 instanceof CrossmintAuthenticationError ? error2.message : "Unable to load oauth providers. Please try again later."
      );
    } finally {
      setIsLoadingOauthUrlMap(false);
    }
  }), [loginMethods, crossmintAuth]);
  useEffect(() => {
    if (preFetchOAuthUrls) {
      preFetchAndSetOauthUrl();
    }
  }, [preFetchAndSetOauthUrl, preFetchOAuthUrls]);
  const handleToggleDialog = (open, successfulLogin) => {
    setDialogOpen == null ? void 0 : setDialogOpen(open, successfulLogin);
    if (!open) {
      setTimeout(() => setStep("initial"), 250);
    }
  };
  const value = {
    step,
    error,
    baseUrl,
    appearance,
    termsOfServiceText,
    authModalTitle,
    loginMethods,
    defaultEmail,
    oauthUrlMap,
    isLoadingOauthUrlMap,
    setDialogOpen: handleToggleDialog,
    setError,
    setStep
  };
  return /* @__PURE__ */ jsx2(AuthFormContext.Provider, { value, children });
};

// src/components/auth/AuthForm.tsx
import Color2 from "color";

// src/components/auth/methods/email/EmailAuthFlow.tsx
import { useState as useState6 } from "react";

// src/components/auth/methods/email/EmailOTPInput.tsx
import { useState as useState3 } from "react";

// src/components/auth/AuthFormBackButton.tsx
import { jsx as jsx3 } from "react/jsx-runtime";
var AuthFormBackButton = (_a) => {
  var _b = _a, {
    className,
    iconColor,
    ringColor,
    onClick
  } = _b, props = __objRest(_b, [
    "className",
    "iconColor",
    "ringColor",
    "onClick"
  ]);
  const { setError } = useAuthForm();
  return /* @__PURE__ */ jsx3(
    "button",
    __spreadProps(__spreadValues({
      className: classNames(
        "absolute left-4 top-4 min-[480px]:!left-6 min-[480px]:!top-6 rounded-full opacity-70 ring-offset-background text-cm-text-primary transition-opacity hover:opacity-100 focus:outline-none focus:ring-2 focus:ring-cm-accent focus:ring-offset-2 disabled:pointer-events-none",
        className
      ),
      onClick: (event) => {
        setError(null);
        onClick == null ? void 0 : onClick(event);
      }
    }, props), {
      children: /* @__PURE__ */ jsx3(LeftArrowIcon, { className: "w-6 h-6", style: { color: iconColor } })
    })
  );
};

// src/components/auth/methods/email/EmailOTPInput.tsx
import { jsx as jsx4, jsxs as jsxs2 } from "react/jsx-runtime";
var EMAIL_VERIFICATION_TOKEN_LENGTH = 6;
function EmailOTPInput({
  otpEmailData,
  setOtpEmailData
}) {
  var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j, _k, _l, _m, _n, _o, _p, _q, _r, _s, _t;
  const { crossmintAuth } = useCrossmintAuth();
  const { appearance, setDialogOpen, setStep, setError } = useAuthForm();
  const [token, setToken] = useState3("");
  const [hasError, setHasError] = useState3(false);
  const [loading, setLoading] = useState3(false);
  const handleOnSubmitOTP = () => __async(this, null, function* () {
    var _a2, _b2;
    setLoading(true);
    try {
      const oneTimeSecret = yield crossmintAuth == null ? void 0 : crossmintAuth.confirmEmailOtp(
        (_a2 = otpEmailData == null ? void 0 : otpEmailData.email) != null ? _a2 : "",
        (_b2 = otpEmailData == null ? void 0 : otpEmailData.emailId) != null ? _b2 : "",
        token
      );
      yield crossmintAuth == null ? void 0 : crossmintAuth.handleRefreshAuthMaterial(oneTimeSecret);
      setDialogOpen(false, true);
      setStep("initial");
    } catch (error) {
      console.error("Error confirming email OTP", error);
      setError("Invalid code. Please try again.");
      setHasError(true);
    } finally {
      setLoading(false);
    }
  });
  const handleOnResendCode = () => __async(this, null, function* () {
    var _a2;
    try {
      yield crossmintAuth == null ? void 0 : crossmintAuth.sendEmailOtp((_a2 = otpEmailData == null ? void 0 : otpEmailData.email) != null ? _a2 : "");
    } catch (_e2) {
      setError("Failed to resend code. Please try again.");
    }
  });
  const handleOnBack = () => {
    setStep("initial");
    setOtpEmailData(null);
  };
  return /* @__PURE__ */ jsxs2("div", { children: [
    /* @__PURE__ */ jsx4(
      AuthFormBackButton,
      {
        onClick: handleOnBack,
        iconColor: (_a = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _a.textPrimary,
        ringColor: (_b = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _b.accent
      }
    ),
    /* @__PURE__ */ jsxs2("div", { className: "flex flex-col items-center justify-start w-full", children: [
      /* @__PURE__ */ jsx4("div", { className: "relative left-3", children: /* @__PURE__ */ jsx4(
        EmailOtpIcon,
        {
          customAccentColor: (_c = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _c.accent,
          customButtonBackgroundColor: (_d = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _d.buttonBackground,
          customBackgroundColor: (_e = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _e.background
        }
      ) }),
      /* @__PURE__ */ jsx4(
        "p",
        {
          className: "text-base font-normal mt-4 mb-1 text-center text-cm-text-primary",
          style: { color: (_f = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _f.textPrimary },
          children: "Check your email"
        }
      ),
      /* @__PURE__ */ jsxs2(
        "p",
        {
          className: "text-center text-cm-text-secondary px-4",
          style: { color: (_g = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _g.textSecondary },
          children: [
            "A temporary login code has been sent to",
            " ",
            (otpEmailData == null ? void 0 : otpEmailData.email) ? otpEmailData.email : "your email address"
          ]
        }
      ),
      /* @__PURE__ */ jsx4("div", { className: "py-8", children: /* @__PURE__ */ jsx4(
        InputOTP,
        {
          maxLength: EMAIL_VERIFICATION_TOKEN_LENGTH,
          value: token,
          onChange: (val) => {
            setToken(val);
            setHasError(false);
            setError(null);
          },
          onComplete: handleOnSubmitOTP,
          disabled: loading,
          customStyles: {
            accent: (_i = (_h = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _h.accent) != null ? _i : "#04AA6D",
            danger: (_k = (_j = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _j.danger) != null ? _k : "#f44336",
            border: (_m = (_l = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _l.border) != null ? _m : "#E5E7EB",
            textPrimary: (_o = (_n = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _n.textPrimary) != null ? _o : "#909ca3",
            buttonBackground: (_q = (_p = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _p.buttonBackground) != null ? _q : "#eff6ff",
            inputBackground: (_s = (_r = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _r.inputBackground) != null ? _s : "#FFFFFF",
            borderRadius: appearance == null ? void 0 : appearance.borderRadius
          },
          children: /* @__PURE__ */ jsxs2(InputOTPGroup, { children: [
            /* @__PURE__ */ jsx4(InputOTPSlot, { index: 0, hasError }),
            /* @__PURE__ */ jsx4(InputOTPSlot, { index: 1, hasError }),
            /* @__PURE__ */ jsx4(InputOTPSlot, { index: 2, hasError }),
            /* @__PURE__ */ jsx4(InputOTPSlot, { index: 3, hasError }),
            /* @__PURE__ */ jsx4(InputOTPSlot, { index: 4, hasError }),
            /* @__PURE__ */ jsx4(InputOTPSlot, { index: 5, hasError })
          ] })
        }
      ) }),
      /* @__PURE__ */ jsx4("div", { className: "text-xs leading-tight text-cm-text-secondary text-center", children: /* @__PURE__ */ jsxs2("span", { style: { color: (_t = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _t.textSecondary }, children: [
        "Can't find the email? Check spam folder.",
        "\n",
        "Some emails may take several minutes to arrive."
      ] }) }),
      /* @__PURE__ */ jsx4(
        CountdownButton,
        {
          initialSeconds: 60,
          appearance,
          countdownText: (seconds) => `Re-send code in ${seconds}s`,
          countdownCompleteText: "Re-send code",
          handleOnClick: handleOnResendCode
        }
      )
    ] })
  ] });
}

// src/components/auth/methods/email/EmailSignIn.tsx
import { useState as useState5 } from "react";
import Color from "color";
import { isEmailValid } from "@crossmint/common-sdk-auth";

// src/hooks/useOAuthWindowListener.ts
import { ChildWindow, PopupWindow } from "@crossmint/client-sdk-window";
import { useEffect as useEffect2, useRef, useState as useState4 } from "react";
import { z } from "zod";
var useOAuthWindowListener = (provider) => {
  const { crossmintAuth } = useCrossmintAuth();
  const { oauthUrlMap, setError } = useAuthForm();
  const [isLoading, setIsLoading] = useState4(false);
  const childRef = useRef(null);
  useEffect2(() => {
    if (childRef.current == null) {
      childRef.current = new ChildWindow(window.opener || window.parent, "*", {
        incomingEvents
      });
    }
    return () => {
      if (childRef.current != null) {
        childRef.current.off("authMaterialFromPopupCallback");
      }
    };
  }, []);
  const createPopupAndSetupListeners = (providerLoginHint) => __async(void 0, null, function* () {
    if (childRef.current == null) {
      throw new Error("Child window not initialized");
    }
    setIsLoading(true);
    setError(null);
    const baseUrl = new URL(oauthUrlMap[provider]);
    if (providerLoginHint != null) {
      const existingParams = Array.from(baseUrl.searchParams.entries());
      baseUrl.search = "";
      if (providerLoginHint) {
        baseUrl.searchParams.append("provider_login_hint", providerLoginHint);
      }
      existingParams.forEach(([key, value]) => {
        baseUrl.searchParams.append(key, value);
      });
    }
    const popup = yield PopupWindow.init(baseUrl.toString(), {
      awaitToLoad: false,
      crossOrigin: true,
      width: 400,
      height: 700
    });
    const handleAuthMaterial = (data) => __async(void 0, null, function* () {
      var _a;
      yield crossmintAuth == null ? void 0 : crossmintAuth.handleRefreshAuthMaterial(data.oneTimeSecret);
      (_a = childRef.current) == null ? void 0 : _a.off("authMaterialFromPopupCallback");
      popup.window.close();
      setIsLoading(false);
    });
    const handleError = (data) => {
      var _a;
      setError(data.error);
      (_a = childRef.current) == null ? void 0 : _a.off("errorFromPopupCallback");
      popup.window.close();
      setIsLoading(false);
    };
    childRef.current.on("authMaterialFromPopupCallback", handleAuthMaterial);
    childRef.current.on("errorFromPopupCallback", handleError);
    const checkWindowClosure = setInterval(() => {
      var _a;
      if (popup.window.closed) {
        clearInterval(checkWindowClosure);
        setIsLoading(false);
        (_a = childRef.current) == null ? void 0 : _a.off("authMaterialFromPopupCallback");
      }
    }, 2500);
  });
  return {
    createPopupAndSetupListeners,
    isLoading
  };
};
var incomingEvents = {
  authMaterialFromPopupCallback: z.object({ oneTimeSecret: z.string() }),
  errorFromPopupCallback: z.object({ error: z.string() })
};

// src/components/auth/methods/google/ContinueWithGoogle.tsx
import { jsx as jsx5, jsxs as jsxs3 } from "react/jsx-runtime";
function ContinueWithGoogle({ emailInput, appearance }) {
  var _a, _b, _c, _d;
  const { createPopupAndSetupListeners, isLoading: isLoadingOAuthWindow } = useOAuthWindowListener("google");
  return /* @__PURE__ */ jsxs3(
    "button",
    {
      type: "button",
      className: classNames(
        "flex items-center gap-2 justify-center h-[32px] px-2.5 border border-cm-border rounded-xl bg-cm-background-primary",
        "hover:bg-cm-hover focus:bg-cm-hover outline-none",
        isLoadingOAuthWindow ? "cursor-not-allowed hover:bg-cm-muted-primary" : ""
      ),
      onClick: isLoadingOAuthWindow ? void 0 : () => createPopupAndSetupListeners(emailInput.trim().toLowerCase()),
      style: {
        backgroundColor: (_a = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _a.buttonBackground,
        borderRadius: appearance == null ? void 0 : appearance.borderRadius
      },
      children: [
        /* @__PURE__ */ jsx5(GoogleIcon, { className: "max-h-[18px] max-w-[18px] h-[18px] w-[18px]" }),
        isLoadingOAuthWindow ? /* @__PURE__ */ jsx5(
          Spinner,
          {
            style: {
              color: (_b = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _b.textSecondary,
              fill: (_c = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _c.textPrimary,
              width: "18px",
              height: "18px"
            }
          }
        ) : /* @__PURE__ */ jsx5("span", { className: "text-cm-accent", style: { color: (_d = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _d.accent }, children: "Continue" })
      ]
    }
  );
}

// src/components/auth/methods/email/EmailSignIn.tsx
import { Fragment, jsx as jsx6, jsxs as jsxs4 } from "react/jsx-runtime";
function EmailSignIn({ setOtpEmailData }) {
  var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j, _k, _l, _m, _n;
  const { crossmintAuth } = useCrossmintAuth();
  const { appearance, defaultEmail, setStep, setError } = useAuthForm();
  const [emailInput, setEmailInput] = useState5(defaultEmail != null ? defaultEmail : "");
  const [emailError, setEmailError] = useState5("");
  const [isLoading, setIsLoading] = useState5(false);
  const showGoogleContinueButton = emailInput.toLowerCase().includes("@gmail.com") && !emailInput.toLowerCase().includes("+") && isEmailValid(emailInput) && !isLoading;
  function handleOnSubmit(e) {
    return __async(this, null, function* () {
      e.preventDefault();
      setIsLoading(true);
      try {
        const trimmedEmailInput = emailInput.trim().toLowerCase();
        const emailSignInRes = yield crossmintAuth == null ? void 0 : crossmintAuth.sendEmailOtp(trimmedEmailInput);
        setOtpEmailData({ email: trimmedEmailInput, emailId: emailSignInRes.emailId });
        setStep("otp");
      } catch (_e2) {
        setIsLoading(false);
        setError("Failed to send email. Please try again or contact support.");
      }
    });
  }
  return /* @__PURE__ */ jsx6(Fragment, { children: /* @__PURE__ */ jsx6("div", { className: "flex flex-col items-start justify-start w-full rounded-lg", children: /* @__PURE__ */ jsxs4("div", { className: "w-full", children: [
    /* @__PURE__ */ jsx6(
      "label",
      {
        className: "text-cm-text-primary block mb-[5px]",
        style: { color: (_a = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _a.textPrimary },
        children: "Email"
      }
    ),
    /* @__PURE__ */ jsxs4(
      "form",
      {
        role: "form",
        className: "relative",
        onSubmit: (e) => {
          if (showGoogleContinueButton) {
            e.preventDefault();
            return;
          }
          if (isEmailValid(emailInput)) {
            handleOnSubmit(e);
          } else {
            e.preventDefault();
          }
        },
        noValidate: true,
        children: [
          /* @__PURE__ */ jsx6("label", { htmlFor: "emailInput", className: "sr-only", children: "Email" }),
          /* @__PURE__ */ jsx6(
            "input",
            {
              className: classNames(
                "flex-grow text-cm-text-primary text-left pl-[16px] h-[58px] w-full border border-cm-border rounded-xl bg-cm-background-primary placeholder:text-md",
                "transition-none duration-200 ease-in-out",
                "focus:outline-none focus-ring-custom",
                // Add focus ring
                "placeholder:[color:var(--placeholder-color)]",
                emailError ? "border-red-500" : "",
                showGoogleContinueButton ? "pr-[132px]" : "pr-[80px]"
              ),
              style: {
                color: (_b = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _b.textPrimary,
                borderRadius: appearance == null ? void 0 : appearance.borderRadius,
                borderColor: emailError ? (_c = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _c.danger : (_d = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _d.border,
                backgroundColor: (_e = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _e.inputBackground,
                // @ts-expect-error Add custom placeholder & ring color to tailwind
                "--placeholder-color": (_g = (_f = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _f.textSecondary) != null ? _g : "#67797F",
                "--focus-ring-color": new Color((_i = (_h = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _h.accent) != null ? _i : "#04AA6D").alpha(0.18).toString()
              },
              type: "email",
              placeholder: "your@email.com",
              value: emailInput,
              onChange: (e) => {
                setEmailInput(e.target.value);
                setEmailError("");
                setError(null);
              },
              readOnly: isLoading,
              "aria-describedby": "emailError"
            }
          ),
          /* @__PURE__ */ jsxs4("div", { className: "absolute inset-y-0 right-0 flex items-center pr-4", children: [
            emailError && /* @__PURE__ */ jsx6(AlertIcon, { customColor: (_j = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _j.danger }),
            isLoading && /* @__PURE__ */ jsx6(
              Spinner,
              {
                style: {
                  color: (_k = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _k.textSecondary,
                  fill: (_l = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _l.textPrimary
                }
              }
            ),
            showGoogleContinueButton ? /* @__PURE__ */ jsx6(ContinueWithGoogle, { emailInput, appearance }) : !emailError && !isLoading ? /* @__PURE__ */ jsx6(
              "button",
              {
                type: "submit",
                className: classNames(
                  "font-medium text-cm-accent text-nowrap bg-cm-background-primary",
                  !isEmailValid(emailInput) ? "!cursor-not-allowed opacity-60" : "cursor-pointer"
                ),
                style: {
                  color: (_m = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _m.accent,
                  backgroundColor: (_n = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _n.inputBackground
                },
                disabled: !isEmailValid(emailInput) || isLoading,
                children: "Submit"
              }
            ) : null
          ] })
        ]
      }
    ),
    emailError && /* @__PURE__ */ jsx6("p", { className: "text-xs text-red-500 mb-2 pt-2", children: emailError })
  ] }) }) });
}

// src/components/auth/methods/email/EmailAuthFlow.tsx
import { jsx as jsx7 } from "react/jsx-runtime";
function EmailAuthFlow() {
  const { step } = useAuthForm();
  const [otpEmailData, setOtpEmailData] = useState6(null);
  if (step === "otp") {
    return /* @__PURE__ */ jsx7(EmailOTPInput, { otpEmailData, setOtpEmailData });
  }
  if (step === "initial") {
    return /* @__PURE__ */ jsx7(EmailSignIn, { setOtpEmailData });
  }
  return null;
}

// src/components/common/Divider.tsx
import { jsx as jsx8, jsxs as jsxs5 } from "react/jsx-runtime";
function Divider({ appearance, text }) {
  var _a, _b, _c;
  const { step } = useAuthForm();
  if (step !== "initial") {
    return null;
  }
  return /* @__PURE__ */ jsxs5("div", { className: "flex items-center justify-center w-full pt-2 pb-3", children: [
    /* @__PURE__ */ jsx8("span", { className: "w-full h-[1px] bg-cm-border", style: { backgroundColor: (_a = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _a.border } }),
    text != null ? /* @__PURE__ */ jsx8(
      "p",
      {
        className: "flex-none px-2 text-sm text-cm-text-primary",
        style: { color: (_b = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _b.textSecondary },
        children: text
      }
    ) : null,
    /* @__PURE__ */ jsx8("span", { className: "w-full h-[1px] bg-cm-border", style: { backgroundColor: (_c = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _c.border } })
  ] });
}

// src/components/auth/methods/google/GoogleSignIn.tsx
import { Fragment as Fragment2, jsx as jsx9, jsxs as jsxs6 } from "react/jsx-runtime";
function GoogleSignIn(_a) {
  var props = __objRest(_a, []);
  var _a2, _b, _c, _d;
  const { step, appearance, isLoadingOauthUrlMap } = useAuthForm();
  const { createPopupAndSetupListeners, isLoading: isLoadingOAuthWindow } = useOAuthWindowListener("google");
  const isLoading = isLoadingOauthUrlMap || isLoadingOAuthWindow;
  if (step !== "initial") {
    return null;
  }
  return /* @__PURE__ */ jsxs6(
    "button",
    __spreadProps(__spreadValues({
      className: classNames(
        "relative flex text-base p-4 bg-cm-muted-primary text-cm-text-primary items-center w-full rounded-xl justify-center",
        "transition-colors duration-200 ease-in-out",
        "hover:bg-cm-hover focus:bg-cm-hover outline-none",
        isLoading ? "cursor-not-allowed hover:bg-cm-muted-primary" : ""
      ),
      style: {
        borderRadius: appearance == null ? void 0 : appearance.borderRadius,
        backgroundColor: (_a2 = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _a2.buttonBackground
      },
      onClick: isLoading ? void 0 : () => createPopupAndSetupListeners()
    }, props), {
      children: [
        /* @__PURE__ */ jsxs6(Fragment2, { children: [
          /* @__PURE__ */ jsx9(GoogleIcon, { className: "max-h-[25px] max-w-[25px] h-[25px] w-[25px] absolute left-[18px]" }),
          isLoading ? /* @__PURE__ */ jsx9(
            Spinner,
            {
              style: {
                color: (_b = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _b.textSecondary,
                fill: (_c = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _c.textPrimary
              }
            }
          ) : /* @__PURE__ */ jsx9(
            "span",
            {
              className: "font-medium",
              style: { margin: "0px 32px", color: (_d = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _d.textPrimary },
              children: "Sign in with Google"
            }
          )
        ] }),
        /* @__PURE__ */ jsx9("span", { className: "sr-only", children: "Sign in with Google" })
      ]
    })
  );
}

// src/components/auth/methods/farcaster/FarcasterSignIn.tsx
import { useEffect as useEffect3, useMemo as useMemo2, useState as useState7 } from "react";
import { useSignIn, QRCode } from "@farcaster/auth-kit";
import { Fragment as Fragment3, jsx as jsx10, jsxs as jsxs7 } from "react/jsx-runtime";
function FarcasterSignIn() {
  var _a, _b;
  const { step, appearance, setStep, setError } = useAuthForm();
  if (step === "initial") {
    return /* @__PURE__ */ jsx10("div", { children: /* @__PURE__ */ jsxs7(
      "button",
      {
        className: classNames(
          "relative flex text-base p-4 bg-cm-muted-primary text-cm-text-primary items-center w-full rounded-xl justify-center",
          "transition-colors duration-200 ease-in-out",
          "hover:bg-cm-hover focus:bg-cm-hover outline-none"
        ),
        style: {
          borderRadius: appearance == null ? void 0 : appearance.borderRadius,
          backgroundColor: (_a = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _a.buttonBackground
        },
        onClick: () => {
          setStep("qrCode");
          setError(null);
        },
        children: [
          /* @__PURE__ */ jsx10(FarcasterIcon, { className: "max-h-[25px] max-w-[25px] h-[25px] w-[25px] absolute left-[18px]" }),
          /* @__PURE__ */ jsx10(
            "span",
            {
              className: "font-medium",
              style: { margin: "0px 32px", color: (_b = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _b.textPrimary },
              children: "Sign in with Farcaster"
            }
          ),
          /* @__PURE__ */ jsx10("span", { className: "sr-only", children: "Sign in with Farcaster" })
        ]
      }
    ) });
  }
  if (step === "qrCode") {
    return /* @__PURE__ */ jsx10(FarcasterQRCode, {});
  }
  return null;
}
function FarcasterQRCode() {
  var _a, _b, _c, _d, _e, _f, _g, _h, _i;
  const { crossmintAuth } = useCrossmintAuth();
  const { appearance, setStep, setDialogOpen, setError } = useAuthForm();
  const [farcasterData, setFarcasterData] = useState7(null);
  const farcasterProps = useMemo2(
    () => ({
      onSuccess: (data) => {
        setFarcasterData(data);
      }
    }),
    []
  );
  const { signIn, url: qrCodeUrl, connect, signOut, isConnected } = useSignIn(farcasterProps);
  const handleFarcasterSignIn = (data) => __async(this, null, function* () {
    setError(null);
    try {
      const oneTimeSecret = yield crossmintAuth == null ? void 0 : crossmintAuth.signInWithFarcaster(data);
      yield crossmintAuth == null ? void 0 : crossmintAuth.handleRefreshAuthMaterial(oneTimeSecret);
      setDialogOpen(false);
      setStep("initial");
    } catch (error) {
      console.error("Error during Farcaster sign-in:", error);
      setError("Failed to sign in with Farcaster");
    }
  });
  useEffect3(() => {
    if (farcasterData != null) {
      handleFarcasterSignIn(farcasterData);
    }
  }, [farcasterData]);
  useEffect3(() => {
    if (isConnected) {
      signIn();
    }
  }, [isConnected]);
  useEffect3(() => {
    connect();
  }, []);
  return /* @__PURE__ */ jsxs7("div", { children: [
    /* @__PURE__ */ jsx10(
      AuthFormBackButton,
      {
        onClick: () => {
          signOut();
          setStep("initial");
        },
        iconColor: (_a = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _a.textPrimary,
        ringColor: (_b = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _b.accent
      }
    ),
    /* @__PURE__ */ jsxs7("div", { className: "flex flex-col items-center gap-4", children: [
      /* @__PURE__ */ jsxs7("div", { className: "text-center", children: [
        /* @__PURE__ */ jsx10(
          "h3",
          {
            className: "text-lg font-semibold text-cm-text-primary mb-2",
            style: { color: (_c = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _c.textPrimary },
            children: "Sign in with Farcaster"
          }
        ),
        /* @__PURE__ */ jsx10(
          "p",
          {
            className: "text-base font-normal text-cm-text-secondary",
            style: { color: (_d = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _d.textSecondary },
            children: "Scan with your phone's camera to continue."
          }
        )
      ] }),
      /* @__PURE__ */ jsx10(
        "div",
        {
          className: "bg-white aspect-square rounded-lg p-4",
          style: {
            backgroundColor: (_e = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _e.inputBackground,
            borderRadius: appearance == null ? void 0 : appearance.borderRadius
          },
          children: qrCodeUrl != null ? /* @__PURE__ */ jsx10(QRCode, { uri: qrCodeUrl, size: 280 }) : /* @__PURE__ */ jsx10("div", { className: "min-h-[246px] flex items-center justify-center", children: /* @__PURE__ */ jsx10(
            Spinner,
            {
              style: {
                color: (_f = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _f.textSecondary,
                fill: (_g = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _g.textPrimary
              }
            }
          ) })
        }
      ),
      qrCodeUrl ? /* @__PURE__ */ jsxs7(Fragment3, { children: [
        /* @__PURE__ */ jsx10(
          "p",
          {
            className: "text-base text-center font-normal text-cm-text-secondary",
            style: { color: (_h = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _h.textSecondary },
            children: "Alternatively, click on this link to open Warpcast."
          }
        ),
        /* @__PURE__ */ jsx10(
          "a",
          {
            href: qrCodeUrl,
            rel: "noopener noreferrer",
            target: "_blank",
            className: "text-base font-normal text-cm-link",
            style: { color: (_i = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _i.textLink },
            children: "Open Warpcast"
          }
        )
      ] }) : null
    ] })
  ] });
}

// src/components/auth/methods/twitter/TwitterSignIn.tsx
import { Fragment as Fragment4, jsx as jsx11, jsxs as jsxs8 } from "react/jsx-runtime";
function TwitterSignIn(_a) {
  var props = __objRest(_a, []);
  var _a2, _b, _c, _d;
  const { step, appearance, isLoadingOauthUrlMap } = useAuthForm();
  const { createPopupAndSetupListeners, isLoading: isLoadingOAuthWindow } = useOAuthWindowListener("twitter");
  const isLoading = isLoadingOauthUrlMap || isLoadingOAuthWindow;
  if (step !== "initial") {
    return null;
  }
  return /* @__PURE__ */ jsxs8(
    "button",
    __spreadProps(__spreadValues({
      className: classNames(
        "relative flex text-base p-4 bg-cm-muted-primary text-cm-text-primary items-center w-full rounded-xl justify-center",
        "transition-colors duration-200 ease-in-out",
        "hover:bg-cm-hover focus:bg-cm-hover outline-none",
        isLoading ? "cursor-not-allowed hover:bg-cm-muted-primary" : ""
      ),
      style: {
        borderRadius: appearance == null ? void 0 : appearance.borderRadius,
        backgroundColor: (_a2 = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _a2.buttonBackground
      },
      onClick: isLoading ? void 0 : () => createPopupAndSetupListeners()
    }, props), {
      children: [
        /* @__PURE__ */ jsxs8(Fragment4, { children: [
          /* @__PURE__ */ jsx11(TwitterIcon, { className: "max-h-[25px] max-w-[25px] h-[25px] w-[25px] absolute left-[18px]" }),
          isLoading ? /* @__PURE__ */ jsx11(
            Spinner,
            {
              style: {
                color: (_b = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _b.textSecondary,
                fill: (_c = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _c.textPrimary
              }
            }
          ) : /* @__PURE__ */ jsx11(
            "span",
            {
              className: "font-medium",
              style: { margin: "0px 32px", color: (_d = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _d.textPrimary },
              children: "Sign in with X"
            }
          )
        ] }),
        /* @__PURE__ */ jsx11("span", { className: "sr-only", children: "Sign in with X" })
      ]
    })
  );
}

// src/components/auth/methods/web3/Web3AuthFlowButton.tsx
import { jsx as jsx12, jsxs as jsxs9 } from "react/jsx-runtime";
function Web3AuthFlowButton() {
  var _a, _b, _c, _d, _e;
  const { step, appearance, setStep, setError } = useAuthForm();
  if (step !== "initial") {
    return null;
  }
  return /* @__PURE__ */ jsxs9(
    "button",
    {
      className: classNames(
        "relative flex text-base p-4 bg-cm-muted-primary text-cm-text-primary items-center w-full rounded-xl justify-center",
        "transition-colors duration-200 ease-in-out",
        "hover:bg-cm-hover focus:bg-cm-hover outline-none"
      ),
      style: {
        borderRadius: appearance == null ? void 0 : appearance.borderRadius,
        borderColor: (_a = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _a.border,
        backgroundColor: (_b = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _b.buttonBackground
      },
      onClick: () => {
        setStep("web3");
        setError(null);
      },
      children: [
        /* @__PURE__ */ jsx12(
          WalletIcon,
          {
            className: "h-[21px] w-[21px] absolute left-[20px]",
            style: { color: (_c = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _c.textPrimary }
          }
        ),
        /* @__PURE__ */ jsx12("span", { className: "font-medium", style: { margin: "0px 32px", color: (_d = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _d.textPrimary }, children: "Continue with a wallet" }),
        /* @__PURE__ */ jsx12(
          ChevronRightIcon,
          {
            className: "h-[21px] w-[21px] absolute right-[20px]",
            style: { color: (_e = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _e.textSecondary }
          }
        ),
        /* @__PURE__ */ jsx12("span", { className: "sr-only", children: "Continue with a wallet" })
      ]
    }
  );
}

// src/components/auth/methods/web3/Web3Connectors.tsx
import { DynamicEmbeddedWidget } from "@dynamic-labs/sdk-react-core";
import { Fragment as Fragment5, jsx as jsx13, jsxs as jsxs10 } from "react/jsx-runtime";
function Web3Connectors() {
  var _a, _b;
  const { appearance, step, setStep } = useAuthForm();
  if (step === "web3") {
    return /* @__PURE__ */ jsxs10(Fragment5, { children: [
      /* @__PURE__ */ jsx13(
        AuthFormBackButton,
        {
          onClick: () => setStep("initial"),
          iconColor: (_a = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _a.textPrimary,
          ringColor: (_b = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _b.accent
        }
      ),
      /* @__PURE__ */ jsx13("div", { className: "flex flex-col items-center", children: /* @__PURE__ */ jsx13("div", { className: "flex flex-col gap-[10px] w-full", children: /* @__PURE__ */ jsx13("div", { className: "widget-container", children: /* @__PURE__ */ jsx13(DynamicEmbeddedWidget, { background: "none" }) }) }) })
    ] });
  }
  return null;
}

// src/components/auth/methods/web3/Web3AuthFlow.tsx
import { jsx as jsx14 } from "react/jsx-runtime";
function Web3AuthFlow() {
  const { step } = useAuthForm();
  if (step.startsWith("web3")) {
    return /* @__PURE__ */ jsx14(Web3Connectors, {});
  }
  if (step === "initial") {
    return /* @__PURE__ */ jsx14(Web3AuthFlowButton, {});
  }
  return null;
}

// src/components/auth/AuthForm.tsx
import { jsx as jsx15, jsxs as jsxs11 } from "react/jsx-runtime";
function AuthForm({ className }) {
  var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j, _k, _l, _m;
  const { step, appearance, loginMethods, baseUrl, error, termsOfServiceText, authModalTitle } = useAuthForm();
  return /* @__PURE__ */ jsxs11(
    "div",
    {
      className: classNames(
        "relative pt-10 pb-[30px] px-6 !min-[480px]:px-10 flex flex-col gap-[10px] antialiased animate-none",
        className
      ),
      children: [
        error != null ? /* @__PURE__ */ jsxs11(
          "div",
          {
            className: "flex items-start justify-start w-full rounded-lg p-2 mt-4 bg-cm-danger-muted",
            style: {
              backgroundColor: new Color2((_b = (_a = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _a.danger) != null ? _b : "#f44336").alpha(0.12).toString()
            },
            children: [
              /* @__PURE__ */ jsx15("div", { className: "min-w-[20px]", children: /* @__PURE__ */ jsx15(AlertIcon, { customColor: (_d = (_c = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _c.danger) != null ? _d : "#f44336" }) }),
              /* @__PURE__ */ jsx15("p", { className: "ml-2 text-sm", style: { color: (_f = (_e = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _e.danger) != null ? _f : "#f44336" }, children: error })
            ]
          }
        ) : null,
        step === "initial" ? /* @__PURE__ */ jsxs11("div", { children: [
          /* @__PURE__ */ jsx15(
            "h1",
            {
              className: "text-2xl font-bold text-cm-text-primary",
              style: { color: (_g = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _g.textPrimary },
              children: authModalTitle != null ? authModalTitle : "Sign in to Crossmint"
            }
          ),
          /* @__PURE__ */ jsx15(
            "p",
            {
              className: "text-base font-normal mb-3 text-cm-text-secondary",
              style: { color: (_h = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _h.textSecondary },
              children: "Access using one of the options below."
            }
          )
        ] }) : null,
        loginMethods.includes("google") ? /* @__PURE__ */ jsx15(GoogleSignIn, {}) : null,
        loginMethods.includes("farcaster") ? /* @__PURE__ */ jsx15(FarcasterProvider, { baseUrl, children: /* @__PURE__ */ jsx15(FarcasterSignIn, {}) }) : null,
        loginMethods.includes("twitter") ? /* @__PURE__ */ jsx15(TwitterSignIn, {}) : null,
        loginMethods.some((method) => method.startsWith("web3")) ? /* @__PURE__ */ jsx15(Web3AuthFlow, {}) : null,
        loginMethods.includes("email") ? /* @__PURE__ */ jsxs11("div", { children: [
          loginMethods.length > 1 ? /* @__PURE__ */ jsx15(Divider, { appearance, text: "OR" }) : null,
          /* @__PURE__ */ jsx15(EmailAuthFlow, {})
        ] }) : null,
        step === "initial" && termsOfServiceText != null ? /* @__PURE__ */ jsxs11(
          "div",
          {
            className: "text-sm text-center text-cm-text-secondary mt-2",
            style: { color: (_i = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _i.textSecondary },
            children: [
              /* @__PURE__ */ jsx15("style", { children: `
                        p a {
                            color: ${(_k = (_j = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _j.textLink) != null ? _k : "#1A74E9"};
                        }
                    ` }),
              termsOfServiceText
            ]
          }
        ) : null,
        step === "initial" || step === "otp" ? /* @__PURE__ */ jsx15(
          SecuredByCrossmint,
          {
            className: "mt-1.5 md:mt-4 justify-center",
            color: (_m = (_l = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _l.textSecondary) != null ? _m : "#67797F"
          }
        ) : null
      ]
    }
  );
}

// src/components/auth/AuthFormDialog.tsx
import { useEffect as useEffect4 } from "react";
import { jsx as jsx16, jsxs as jsxs12 } from "react/jsx-runtime";
function AuthFormDialog({ open }) {
  var _a, _b, _c;
  const { appearance, setDialogOpen } = useAuthForm();
  useEffect4(() => {
    document.body.style.overflow = open ? "hidden" : "";
  }, [open]);
  return /* @__PURE__ */ jsx16(Dialog, { modal: false, open, onOpenChange: setDialogOpen, children: /* @__PURE__ */ jsxs12(
    DialogContent,
    {
      onInteractOutside: (e) => e.preventDefault(),
      onOpenAutoFocus: (e) => e.preventDefault(),
      closeButtonColor: (_a = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _a.textPrimary,
      closeButtonRingColor: (_b = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _b.accent,
      className: "!p-0 !min-[480px]:p-0",
      style: {
        borderRadius: appearance == null ? void 0 : appearance.borderRadius,
        backgroundColor: (_c = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _c.background
      },
      children: [
        /* @__PURE__ */ jsx16(VisuallyHidden, { asChild: true, children: /* @__PURE__ */ jsx16(DialogTitle, { children: "Crossmint Auth" }) }),
        /* @__PURE__ */ jsx16(VisuallyHidden, { asChild: true, children: /* @__PURE__ */ jsx16(DialogDescription, { children: "Sign in via Crossmint" }) }),
        /* @__PURE__ */ jsx16(AuthForm, { className: "max-w-[448px]" })
      ]
    }
  ) });
}

// src/providers/auth/web3/DynamicWeb3WalletConnect.tsx
import base58 from "bs58";
import { EthereumWalletConnectors } from "@dynamic-labs/ethereum";
import { SolanaWalletConnectors } from "@dynamic-labs/solana";
import { jsx as jsx17 } from "react/jsx-runtime";
function DynamicWeb3WalletConnect({
  children,
  apiKeyEnvironment,
  enabled
}) {
  var _a, _b;
  const { crossmintAuth } = useCrossmintAuth();
  const { appearance, loginMethods } = useAuthForm();
  let connectors = enabled ? [EthereumWalletConnectors, SolanaWalletConnectors] : void 0;
  if (loginMethods.includes("web3:evm-only")) {
    connectors = [EthereumWalletConnectors];
  } else if (loginMethods.includes("web3:solana-only")) {
    connectors = [SolanaWalletConnectors];
  }
  const cssOverrides = `.powered-by-dynamic { display: none !important; } .wallet-list__scroll-container { padding: 0px !important; } .wallet-list__search-container { padding-left: 0px !important; padding-right: 0px !important; } .dynamic-footer { display: none !important; } h1 { color: ${(_a = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _a.textPrimary} !important; } * { color: ${(_b = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _b.textSecondary} !important; }`;
  return /* @__PURE__ */ jsx17(
    DynamicContextProviderWrapper,
    {
      apiKeyEnvironment,
      settings: {
        walletConnectors: connectors,
        cssOverrides,
        events: {
          onWalletRemoved() {
            console.log("[CryptoWalletConnectionHandler] onWalletRemoved");
          },
          onAuthFlowCancel() {
            console.log("[CryptoWalletConnectionHandler] onAuthFlowCancel");
          },
          onAuthFlowClose() {
            console.log("[CryptoWalletConnectionHandler] onAuthFlowClose");
          },
          onAuthFailure(data, reason) {
            console.error("[CryptoWalletConnectionHandler] onAuthFailure", data, reason);
          },
          onAuthSuccess(data) {
            console.log("[CryptoWalletConnectionHandler] onAuthSuccess", data);
          }
        },
        handlers: {
          handleConnectedWallet: (args) => __async(this, null, function* () {
            var _a2;
            console.log("[CryptoWalletConnectionHandler] handleConnectedWallet", args);
            const address = args.address;
            if (!address) {
              console.error("[CryptoWalletConnectionHandler] handleConnectedWallet: address is missing");
              return false;
            }
            const chain = yield dynamicChainToCrossmintChain(args);
            const type = chain === "solana" ? "solana" : "evm";
            try {
              const res = yield crossmintAuth == null ? void 0 : crossmintAuth.signInWithSmartWallet(address, type);
              const rawSignature = yield (_a2 = args.connector) == null ? void 0 : _a2.proveOwnership(
                address,
                res.challenge
              );
              let signature = rawSignature;
              if (type === "solana") {
                const signatureBuffer = Buffer.from(rawSignature, "base64");
                signature = base58.encode(signatureBuffer);
              }
              const authResponse = yield crossmintAuth == null ? void 0 : crossmintAuth.authenticateSmartWallet(
                address,
                type,
                signature
              );
              const oneTimeSecret = authResponse.oneTimeSecret;
              yield crossmintAuth == null ? void 0 : crossmintAuth.handleRefreshAuthMaterial(oneTimeSecret);
            } catch (error) {
              console.error("[CryptoWalletConnectionHandler] Error authenticating wallet:", error);
              false;
            }
            return true;
          })
        }
      },
      children
    },
    `${apiKeyEnvironment}-${loginMethods.join(",")}`
  );
}

// src/providers/CrossmintAuthProvider.tsx
import { jsx as jsx18, jsxs as jsxs13 } from "react/jsx-runtime";
var defaultContextValue = {
  crossmintAuth: void 0,
  login: () => {
  },
  logout: () => {
  },
  jwt: void 0,
  user: void 0,
  status: "initializing",
  getUser: () => {
  }
};
var AuthContext = createContext3(defaultContextValue);
var defaultEmbeddedWallets = {
  createOnLogin: "off",
  type: "evm-smart-wallet",
  experimental_enableRecoveryKeys: false
};
function CrossmintAuthProvider({
  embeddedWallets = defaultEmbeddedWallets,
  children,
  appearance,
  termsOfServiceText,
  prefetchOAuthUrls = true,
  authModalTitle,
  onLoginSuccess,
  loginMethods = ["email", "google"],
  refreshRoute,
  logoutRoute
}) {
  var _a;
  const [user, setUser] = useState8(void 0);
  const { crossmint, setJwt } = useCrossmint("CrossmintAuthProvider must be used within CrossmintProvider");
  const crossmintAuthRef = useRef2(null);
  const crossmintAuth = useMemo3(() => {
    if (!crossmintAuthRef.current) {
      crossmintAuthRef.current = CrossmintAuth.from(crossmint, {
        callbacks: {
          onLogout: () => {
            setJwt(void 0);
            setUser(void 0);
          },
          onTokenRefresh: (authMaterial) => {
            setJwt(authMaterial.jwt);
            setUser(authMaterial.user);
          }
        },
        refreshRoute,
        logoutRoute
      });
    }
    return crossmintAuthRef.current;
  }, []);
  const crossmintBaseUrl = validateApiKeyAndGetCrossmintBaseUrl(crossmint.apiKey);
  const [dialogOpen, setDialogOpen] = useState8(false);
  const [initialized, setInitialized] = useState8(false);
  const [defaultEmail, setDefaultEmail] = useState8(void 0);
  const [isDynamicSdkLoaded, setIsDynamicSdkLoaded] = useState8(false);
  const isWeb3Enabled = loginMethods.some((method) => method.startsWith("web3"));
  const triggerHasJustLoggedIn = useCallback2(() => {
    onLoginSuccess == null ? void 0 : onLoginSuccess();
  }, [onLoginSuccess]);
  useEffect5(() => {
    if (crossmint.jwt == null) {
      const jwt = getCookie(SESSION_PREFIX);
      setJwt(jwt);
    }
    setInitialized(true);
  }, [crossmint.jwt, setJwt]);
  useEffect5(() => {
    if (crossmint.jwt != null && dialogOpen) {
      setDialogOpen(false);
      triggerHasJustLoggedIn();
    }
  }, [crossmint.jwt, dialogOpen, triggerHasJustLoggedIn]);
  const login = useCallback2(
    (defaultEmail2) => {
      if (crossmint.jwt != null) {
        console.log("User already logged in");
        return;
      }
      if (defaultEmail2 != null && typeof defaultEmail2 === "string") {
        setDefaultEmail(defaultEmail2);
      }
      setDialogOpen(true);
    },
    [crossmint.jwt]
  );
  const logout = useCallback2(() => {
    crossmintAuth.logout();
  }, [crossmintAuth]);
  const getAuthStatus = useCallback2(() => {
    if (!initialized) {
      return "initializing";
    }
    if (isWeb3Enabled && !isDynamicSdkLoaded) {
      return "initializing";
    }
    if (crossmint.jwt != null) {
      return "logged-in";
    }
    if (dialogOpen) {
      return "in-progress";
    }
    return "logged-out";
  }, [initialized, crossmint.jwt, dialogOpen, isDynamicSdkLoaded, isWeb3Enabled]);
  const getUser = useCallback2(() => __async(this, null, function* () {
    if (crossmint.jwt == null) {
      console.log("User not logged in");
      return;
    }
    const user2 = yield crossmintAuth.getUser();
    setUser(user2);
  }), [crossmint.jwt, crossmintAuth]);
  const authContextValue = useMemo3(
    () => ({
      crossmintAuth,
      login,
      logout,
      jwt: crossmint.jwt,
      user,
      status: getAuthStatus(),
      getUser
    }),
    [crossmintAuth, login, logout, crossmint.jwt, user, getAuthStatus, getUser]
  );
  return /* @__PURE__ */ jsx18(TwindProvider, { children: /* @__PURE__ */ jsx18(AuthContext.Provider, { value: authContextValue, children: /* @__PURE__ */ jsx18(
    CrossmintWalletProvider,
    {
      showPasskeyHelpers: embeddedWallets.showPasskeyHelpers,
      appearance,
      experimental_enableRecoveryKeys: (_a = embeddedWallets.experimental_enableRecoveryKeys) != null ? _a : false,
      children: /* @__PURE__ */ jsx18(
        AuthFormProvider,
        {
          setDialogOpen: (open, successfulLogin) => {
            setDialogOpen(open);
            if (successfulLogin) {
              triggerHasJustLoggedIn();
            }
          },
          preFetchOAuthUrls: getAuthStatus() === "logged-out" && prefetchOAuthUrls,
          initialState: {
            appearance,
            loginMethods,
            termsOfServiceText,
            authModalTitle,
            embeddedWallets,
            baseUrl: crossmintBaseUrl,
            defaultEmail
          },
          children: /* @__PURE__ */ jsxs13(
            DynamicWeb3WalletConnect,
            {
              enabled: isWeb3Enabled,
              apiKeyEnvironment: crossmint.apiKey.includes("production") ? "production" : "staging",
              children: [
                /* @__PURE__ */ jsx18(
                  WalletManager,
                  {
                    embeddedWallets,
                    accessToken: crossmint.jwt,
                    setIsDynamicSdkLoaded,
                    isWeb3Enabled
                  }
                ),
                children,
                /* @__PURE__ */ jsx18(AuthFormDialog, { open: dialogOpen })
              ]
            }
          )
        }
      )
    },
    crossmint.jwt
  ) }) });
}
function WalletManager({
  embeddedWallets,
  accessToken,
  setIsDynamicSdkLoaded,
  isWeb3Enabled
}) {
  const { getOrCreateWallet, clearWallet, status: walletStatus } = useWallet();
  const { sdkHasLoaded, getAdminSigner, cleanup, isDynamicWalletConnected } = useDynamicConnect(
    isWeb3Enabled,
    setIsDynamicSdkLoaded,
    accessToken
  );
  const { createOnLogin, adminSigner: defaultAdminSigner, linkedUser } = embeddedWallets;
  const canGetOrCreateWallet = createOnLogin === "all-users" && walletStatus === "not-loaded" && accessToken != null && sdkHasLoaded;
  const handleWalletCreation = useCallback2(() => __async(this, null, function* () {
    var _a, _b;
    if (!canGetOrCreateWallet) {
      return;
    }
    let adminSigner = defaultAdminSigner;
    let walletType = embeddedWallets.type;
    if (isDynamicWalletConnected) {
      adminSigner = (_a = yield getAdminSigner()) != null ? _a : adminSigner;
      walletType = (_b = mapSignerToWalletType(adminSigner == null ? void 0 : adminSigner.type)) != null ? _b : walletType;
    }
    if (!isDynamicWalletConnected && embeddedWallets.type == null) {
      console.error(
        "[CrossmintAuthProvider] \u26A0\uFE0F embeddedWallets.type is required when no external wallet is connected"
      );
      return;
    }
    getOrCreateWallet({
      type: walletType,
      args: {
        adminSigner,
        linkedUser
      }
    });
  }), [canGetOrCreateWallet, getOrCreateWallet, linkedUser, defaultAdminSigner, embeddedWallets.type, getAdminSigner]);
  const handleWalletCleanup = useCallback2(() => {
    if (accessToken == null && walletStatus === "loaded") {
      clearWallet();
    }
    cleanup();
  }, [walletStatus, accessToken, clearWallet, cleanup]);
  useEffect5(() => {
    handleWalletCreation();
    handleWalletCleanup();
  }, [handleWalletCreation, handleWalletCleanup]);
  return null;
}

// src/hooks/useAuth.ts
function useAuth() {
  const context = useContext4(AuthContext);
  if (context === void 0) {
    throw new Error("useAuth must be used within an AuthProvider");
  }
  return context;
}

// src/providers/signers/CrossmintSignerProvider.tsx
import { jsx as jsx19, jsxs as jsxs14 } from "react/jsx-runtime";
var DEFAULT_EVENT_OPTIONS = {
  timeoutMs: 1e4,
  intervalMs: 5e3
};
var CrossmintSignerContext = createContext4(null);
function CrossmintSignerProvider({ children, setWalletState, appearance }) {
  const {
    crossmint: { apiKey, jwt }
  } = useCrossmint();
  const smartWalletSDK = useMemo4(() => CrossmintWallets2.from({ apiKey, jwt }), [apiKey, jwt]);
  const [step, setStep] = useState9("initial");
  const [dialogOpen, setDialogOpen] = useState9(false);
  const iframeWindow = useSignerIFrameWindow();
  const successHandlerRef = useRef3(null);
  const errorHandlerRef = useRef3(null);
  const experimental_getOrCreateWalletWithRecoveryKey = (args) => __async(this, null, function* () {
    var _a;
    if (args.type !== "solana") {
      throw new Error("Unsupported wallet type, only solana is supported at the moment");
    }
    if (!iframeWindow.current) {
      throw new Error("IFrame window not initialized");
    }
    try {
      setWalletState({ status: "in-progress" });
      const signerResponse = yield (_a = iframeWindow.current) == null ? void 0 : _a.sendAction({
        event: "request:get-public-key",
        responseEvent: "response:get-public-key",
        data: {
          authData: {
            jwt,
            apiKey
          },
          data: {
            chainLayer: "solana"
          }
        }
      });
      if (signerResponse.status === "success") {
        yield getOrCreateSolanaWalletWithSigner(signerResponse.publicKey);
        return;
      }
      if (args.email != null) {
        yield handleEmailSubmit(args.email);
        return;
      }
      return new Promise((resolve, reject) => {
        setDialogOpen(true);
        setStep("initial");
        const cleanup = () => {
          setDialogOpen(false);
          setStep("initial");
        };
        const successHandler = () => {
          cleanup();
          resolve();
        };
        const errorHandler = (error) => {
          cleanup();
          reject(error);
        };
        successHandlerRef.current = successHandler;
        errorHandlerRef.current = errorHandler;
      });
    } catch (error) {
      console.error("There was an error creating a wallet ", error);
      setWalletState(deriveWalletErrorState(error));
      throw error;
    }
  });
  const handleOnGetOrCreateRecoveryKey = (email) => __async(this, null, function* () {
    var _a;
    try {
      if (!iframeWindow.current) {
        throw new Error("IFrame window not initialized");
      }
      if (jwt == null) {
        throw new Error("JWT not set");
      }
      console.log("Creating Recovery Key");
      const res = yield (_a = iframeWindow.current) == null ? void 0 : _a.sendAction({
        event: "request:create-signer",
        responseEvent: "response:create-signer",
        data: {
          authData: {
            jwt,
            apiKey
          },
          data: {
            chainLayer: "solana",
            authId: `email:${email}`
          }
        }
      });
      if (res.status === "error") {
        throw new Error(res.error);
      }
      if (res.status === "success" && res.address != null) {
        yield getOrCreateSolanaWalletWithSigner(res.address);
        setStep("initial");
        setDialogOpen(false);
      }
    } catch (err) {
      console.error("There was an error creating a recovery key ", err);
      throw err;
    }
  });
  const handleEmailSubmit = (email) => __async(this, null, function* () {
    var _a;
    try {
      yield handleOnGetOrCreateRecoveryKey(email);
      setStep("otp");
      setDialogOpen(true);
    } catch (error) {
      console.error("Error in email submission:", error);
      (_a = errorHandlerRef.current) == null ? void 0 : _a.call(errorHandlerRef, error);
      throw error;
    }
  });
  const handleOTPSubmit = (token) => __async(this, null, function* () {
    var _a, _b;
    if (!iframeWindow.current) {
      throw new Error("IFrame window not initialized");
    }
    if (jwt == null) {
      throw new Error("JWT not set");
    }
    try {
      const res = yield iframeWindow.current.sendAction({
        event: "request:send-otp",
        responseEvent: "response:send-otp",
        data: {
          authData: {
            jwt,
            apiKey
          },
          data: {
            encryptedOtp: token,
            chainLayer: "solana"
          }
        }
      });
      if (res.status === "error") {
        throw new Error(res.error);
      }
      yield getOrCreateSolanaWalletWithSigner(res.address);
      setStep("initial");
      setDialogOpen(false);
      (_a = successHandlerRef.current) == null ? void 0 : _a.call(successHandlerRef);
    } catch (error) {
      console.error("Error in OTP submission:", error);
      (_b = errorHandlerRef.current) == null ? void 0 : _b.call(errorHandlerRef, error);
      throw error;
    }
  });
  function getOrCreateSolanaWalletWithSigner(publicSignerAddress) {
    return __async(this, null, function* () {
      if (jwt == null) {
        throw new Error("[getOrCreateSolanaWalletWithSigner] JWT not set!");
      }
      try {
        const wallet = yield smartWalletSDK.getOrCreateWallet("solana-smart-wallet", {
          adminSigner: {
            type: "solana-keypair",
            address: publicSignerAddress,
            signer: {
              signMessage: (message) => __async(this, null, function* () {
                if (iframeWindow.current == null) {
                  throw new Error("IFrame window not initialized");
                }
                const res = yield iframeWindow.current.sendAction({
                  event: "request:sign-message",
                  responseEvent: "response:sign-message",
                  data: {
                    authData: {
                      jwt,
                      apiKey
                    },
                    data: {
                      message: base582.encode(message),
                      chainLayer: "solana",
                      encoding: "base58"
                    }
                  },
                  options: DEFAULT_EVENT_OPTIONS
                });
                if (res.status === "error") {
                  throw new Error(res.error);
                }
                if (res.signature == null) {
                  throw new Error("Failed to sign message");
                }
                return base582.decode(res.signature);
              }),
              signTransaction: (transaction) => __async(this, null, function* () {
                var _a;
                console.log("Signing transaction...", transaction);
                const res = yield (_a = iframeWindow.current) == null ? void 0 : _a.sendAction({
                  event: "request:sign-transaction",
                  responseEvent: "response:sign-transaction",
                  data: {
                    authData: {
                      jwt,
                      apiKey
                    },
                    data: {
                      transaction: base582.encode(transaction.serialize()),
                      chainLayer: "solana",
                      encoding: "base58"
                    }
                  },
                  options: DEFAULT_EVENT_OPTIONS
                });
                if ((res == null ? void 0 : res.status) === "error") {
                  throw new Error(res.error);
                }
                if ((res == null ? void 0 : res.signature) == null) {
                  throw new Error("Failed to sign transaction");
                }
                transaction.addSignature(new PublicKey(publicSignerAddress), base582.decode(res.signature));
                return transaction;
              })
            }
          }
        });
        setWalletState({ status: "loaded", wallet, type: "solana-smart-wallet" });
      } catch (error) {
        console.error("Error creating wallet with signer:", error);
        setWalletState(deriveWalletErrorState(error));
        throw error;
      }
    });
  }
  useEffect6(() => {
    document.body.style.overflow = dialogOpen ? "hidden" : "";
  }, [dialogOpen]);
  return /* @__PURE__ */ jsxs14(CrossmintSignerContext.Provider, { value: { experimental_getOrCreateWalletWithRecoveryKey }, children: [
    /* @__PURE__ */ jsx19(
      EmailSignersDialog,
      {
        open: dialogOpen,
        setOpen: setDialogOpen,
        step,
        setStep,
        onSubmitOTP: handleOTPSubmit,
        onResendOTPCode: (email) => __async(this, null, function* () {
          yield handleOnGetOrCreateRecoveryKey(email);
          setStep("otp");
        }),
        onSubmitEmail: handleEmailSubmit,
        appearance
      }
    ),
    children
  ] });
}
function useCrossmintSigner({ enabled = true } = {}) {
  const context = useContext5(CrossmintSignerContext);
  if (!enabled) {
    return {
      experimental_getOrCreateWalletWithRecoveryKey: () => __async(this, null, function* () {
        yield Promise.reject(
          new Error("useCrossmintSigner is disabled, please set 'experimental_enableRecoveryKeys' to true")
        );
      })
    };
  }
  if (context === null) {
    throw new Error("useCrossmintSigner must be used within a CrossmintSignerProvider");
  }
  return context;
}

export {
  CrossmintSignerContext,
  CrossmintSignerProvider,
  useCrossmintSigner,
  WalletContext,
  CrossmintWalletProvider,
  useWallet,
  useCrossmintAuth,
  useAuthForm,
  AuthFormProvider,
  AuthFormBackButton,
  EMAIL_VERIFICATION_TOKEN_LENGTH,
  EmailOTPInput,
  useOAuthWindowListener,
  ContinueWithGoogle,
  EmailSignIn,
  EmailAuthFlow,
  Divider,
  GoogleSignIn,
  FarcasterSignIn,
  TwitterSignIn,
  Web3AuthFlowButton,
  Web3Connectors,
  Web3AuthFlow,
  AuthForm,
  AuthFormDialog,
  DynamicWeb3WalletConnect,
  AuthContext,
  CrossmintAuthProvider,
  useAuth
};
//# sourceMappingURL=chunk-TOCRVS5A.js.map