import {
  PayerConnectionHandler
} from "./chunk-WVM3I3I3.js";
import {
  createCrossmintApiClient
} from "./chunk-F3AMLCQL.js";
import {
  useCrossmint
} from "./chunk-3J6CUUWT.js";
import {
  __spreadProps,
  __spreadValues
} from "./chunk-CRTRMMJ7.js";

// src/components/embed/v3/EmbeddedCheckoutV3IFrame.tsx
import { lazy, useEffect, useRef, useState } from "react";
import {
  crossmintEmbeddedCheckoutV3Service
} from "@crossmint/client-sdk-base";
import { Fragment, jsx, jsxs } from "react/jsx-runtime";
var CryptoWalletConnectionHandler = lazy(
  () => (
    // @ts-expect-error - Error because we dont use 'module' field in tsconfig, which is expected because we use tsup to compile
    import("./components/embed/v3/crypto/CryptoWalletConnectionHandler.js").then((mod) => ({
      default: mod.CryptoWalletConnectionHandler
    }))
  )
);
function EmbeddedCheckoutV3IFrame(props) {
  var _a;
  const [iframeClient, setIframeClient] = useState(null);
  const [height, setHeight] = useState(0);
  const initialChainRef = useRef((_a = props.payment.crypto.payer) == null ? void 0 : _a.initialChain);
  const memoizedProps = useRef(props);
  if (havePropsChanged(props, memoizedProps.current)) {
    const newProps = __spreadValues({}, props);
    const initialChainPreservation = shouldPreserveInitialChain(props, initialChainRef.current);
    if (initialChainPreservation.shouldPreserve) {
      newProps.payment.crypto.payer = initialChainPreservation.updatedPayer;
    }
    memoizedProps.current = newProps;
  }
  const { crossmint } = useCrossmint();
  const apiClient = createCrossmintApiClient(crossmint, {
    usageOrigin: "client"
  });
  const embeddedCheckoutService = crossmintEmbeddedCheckoutV3Service({ apiClient });
  const ref = useRef(null);
  useEffect(() => {
    const iframe = ref.current;
    if (!iframe || iframeClient) {
      return;
    }
    setIframeClient(embeddedCheckoutService.iframe.createClient(iframe));
  }, [ref.current, iframeClient]);
  useEffect(() => {
    if (iframeClient == null) {
      return;
    }
    iframeClient.on("ui:height.changed", (data) => setHeight(data.height));
    return () => {
      iframeClient.off("ui:height.changed");
    };
  }, [iframeClient]);
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx(
      "iframe",
      {
        ref,
        src: embeddedCheckoutService.iframe.getUrl(memoizedProps.current),
        id: "crossmint-embedded-checkout.iframe",
        role: "crossmint-embedded-checkout.iframe",
        allow: "payment *",
        style: {
          boxShadow: "none",
          border: "none",
          padding: "0px",
          width: "100%",
          minWidth: "100%",
          overflow: "hidden",
          display: "block",
          userSelect: "none",
          transform: "translate(0px)",
          opacity: "1",
          transition: "ease 0s, opacity 0.4s ease 0.1s",
          height: `${height}px`,
          backgroundColor: "transparent"
        }
      }
    ),
    memoizedProps.current.payment.crypto.enabled ? memoizedProps.current.payment.crypto.payer != null ? /* @__PURE__ */ jsx(
      PayerConnectionHandler,
      {
        payer: memoizedProps.current.payment.crypto.payer,
        iframeClient
      }
    ) : /* @__PURE__ */ jsx(
      CryptoWalletConnectionHandler,
      {
        iframeClient,
        apiKeyEnvironment: apiClient["parsedAPIKey"].environment
      }
    ) : null,
    /* @__PURE__ */ jsx("span", { id: "crossmint-focus-target", tabIndex: -1 })
  ] });
}
function havePropsChanged(parentProps, currentRefProps) {
  return JSON.stringify(parentProps) !== JSON.stringify(currentRefProps);
}
function shouldPreserveInitialChain(props, storedInitialChain) {
  if (props.payment.crypto.payer && storedInitialChain != null) {
    return {
      shouldPreserve: true,
      updatedPayer: __spreadProps(__spreadValues({}, props.payment.crypto.payer), {
        initialChain: storedInitialChain
      })
    };
  }
  return { shouldPreserve: false };
}

export {
  EmbeddedCheckoutV3IFrame
};
//# sourceMappingURL=chunk-YWGWSNTU.js.map