import {
  handleSendTransaction
} from "../../../../chunk-FU74NHZW.js";
import {
  ChainNotSupportedError,
  dynamicChainToCrossmintChain
} from "../../../../chunk-7HENIDX5.js";
import {
  DynamicContextProviderWrapper
} from "../../../../chunk-F2AWZC4M.js";
import {
  __async,
  __spreadValues
} from "../../../../chunk-CRTRMMJ7.js";

// src/components/embed/v3/crypto/CryptoWalletConnectionHandler.tsx
import {
  blockchainToChainId
} from "@crossmint/common-sdk-base";
import { EthereumWalletConnectors } from "@dynamic-labs/ethereum";
import { DynamicContext, useDynamicContext } from "@dynamic-labs/sdk-react-core";
import { SolanaWalletConnectors } from "@dynamic-labs/solana";
import { SuiWalletConnectors } from "@dynamic-labs/sui";
import { useContext, useEffect, useState } from "react";
import { jsx } from "react/jsx-runtime";
function CryptoWalletConnectionHandler(props) {
  const { iframeClient, apiKeyEnvironment } = props;
  return /* @__PURE__ */ jsx(
    DynamicContextProviderWrapper,
    {
      apiKeyEnvironment,
      settings: {
        walletConnectors: [EthereumWalletConnectors, SolanaWalletConnectors, SuiWalletConnectors],
        events: {
          onAuthFlowCancel() {
            console.log("[CryptoWalletConnectionHandler] onAuthFlowCancel");
            iframeClient == null ? void 0 : iframeClient.send("crypto:connect-wallet.failed", {
              error: "Wallet connection was cancelled"
            });
          },
          onAuthFlowClose() {
            console.log("[CryptoWalletConnectionHandler] onAuthFlowClose");
          },
          onAuthFailure(data, reason) {
            console.error("[CryptoWalletConnectionHandler] onAuthFailure", data, reason);
          },
          onAuthSuccess(data) {
            console.log("[CryptoWalletConnectionHandler] onAuthSuccess", data);
          }
        },
        handlers: {
          handleConnectedWallet: (wallet) => __async(this, null, function* () {
            var _a, _b;
            console.log("[CryptoWalletConnectionHandler] handleConnectedWallet", wallet);
            const address = wallet.address;
            if (!address) {
              console.error(
                "[CryptoWalletConnectionHandler] Failed to connect wallet: Could not retrieve wallet address"
              );
              iframeClient == null ? void 0 : iframeClient.send("crypto:connect-wallet.failed", {
                error: "Could not retrieve wallet address. Please ensure your wallet is properly connected and try again."
              });
              return false;
            }
            let chain;
            try {
              chain = yield dynamicChainToCrossmintChain(wallet);
            } catch (e) {
              if (e instanceof ChainNotSupportedError) {
                const defaultCrossmintChain = apiKeyEnvironment === "production" ? "ethereum" : "ethereum-sepolia";
                const defaultChainId = blockchainToChainId(defaultCrossmintChain);
                try {
                  yield (_a = wallet == null ? void 0 : wallet.connector) == null ? void 0 : _a.switchNetwork({
                    networkChainId: defaultChainId
                  });
                  chain = defaultCrossmintChain;
                } catch (switchNetworkError) {
                  console.error(
                    `[CryptoWalletConnectionHandler] Failed to switch to default chain ${defaultChainId}`,
                    switchNetworkError
                  );
                  iframeClient == null ? void 0 : iframeClient.send("crypto:connect-wallet.failed", {
                    error: `Chain with id ${e.chainId} is not supported. Please change the network in your wallet and try again.`
                  });
                  return false;
                }
              } else {
                throw e;
              }
            }
            iframeClient == null ? void 0 : iframeClient.send("crypto:connect-wallet.success", {
              address,
              chain,
              walletProviderKey: (_b = wallet.connector) == null ? void 0 : _b.key
            });
            return true;
          })
        }
      },
      children: /* @__PURE__ */ jsx(_CryptoWalletConnectionHandler, __spreadValues({}, props))
    }
  );
}
function _CryptoWalletConnectionHandler({ iframeClient }) {
  const [showDynamicModal, setShowDynamicModal] = useState(false);
  const { primaryWallet } = useDynamicContext();
  useEffect(() => {
    if (iframeClient == null) {
      return;
    }
    const showAuthFlowListener = iframeClient.on("crypto:connect-wallet.show", ({ show }) => {
      setShowDynamicModal(show);
    });
    return () => {
      iframeClient.off(showAuthFlowListener);
    };
  }, [iframeClient]);
  useEffect(() => {
    if (iframeClient == null) {
      return;
    }
    const signTransactionListener = iframeClient.on(
      "crypto:send-transaction",
      (_0) => __async(this, [_0], function* ({ chain, serializedTransaction }) {
        if (primaryWallet == null) {
          console.error("[CryptoWalletConnectionHandler] signTransaction: primaryWallet is missing");
          iframeClient.send("crypto:send-transaction:failed", {
            error: "primaryWallet is missing"
          });
          return;
        }
        yield handleSendTransaction(
          primaryWallet,
          chain,
          serializedTransaction,
          iframeClient
        );
      })
    );
    return () => {
      iframeClient.off(signTransactionListener);
    };
  }, [iframeClient, primaryWallet]);
  return showDynamicModal ? /* @__PURE__ */ jsx(ShowDynamicModal, { setShowDynamicModal }) : null;
}
function ShowDynamicModal({ setShowDynamicModal }) {
  const context = useContext(DynamicContext);
  if (context == null) {
    throw new Error("DynamicContext is missing");
  }
  const { setShowAuthFlow, handleLogOut } = context;
  useEffect(() => {
    var _a;
    (_a = document.getElementById("crossmint-focus-target")) == null ? void 0 : _a.focus();
    (() => __async(this, null, function* () {
      yield handleLogOut();
      setShowAuthFlow(true, {
        clearErrors: true,
        emitCancelAuth: true,
        ignoreIfIsEmbeddedWidget: true,
        initializeWalletConnect: true,
        performMultiWalletChecks: false
        // Important to be false in order to not require double clicking connect button
      });
      setShowDynamicModal(false);
    }))();
  }, []);
  return null;
}
export {
  CryptoWalletConnectionHandler,
  ShowDynamicModal
};
//# sourceMappingURL=CryptoWalletConnectionHandler.js.map