import {
  __async
} from "../../../../../chunk-CRTRMMJ7.js";

// src/components/embed/v3/crypto/utils/handleEvmTransaction.ts
import {
  blockchainToChainId
} from "@crossmint/common-sdk-base";
import { isEthereumWallet } from "@dynamic-labs/ethereum";
import { parseTransaction } from "viem";
function handleEvmTransaction(_0) {
  return __async(this, arguments, function* ({
    primaryWallet,
    chain,
    serializedTransaction,
    iframeClient
  }) {
    const { connector } = primaryWallet;
    const chainId = blockchainToChainId(chain);
    try {
      yield connector.switchNetwork({ networkChainId: chainId });
    } catch (error) {
      console.error(`[CryptoWalletConnectionHandler] failed to switch network to ${chainId}`, error);
      iframeClient.send("crypto:send-transaction:failed", {
        error: error.message
      });
      return;
    }
    let walletClient;
    try {
      if (!isEthereumWallet(primaryWallet)) {
        throw new Error("primaryWallet is not an ethereum wallet");
      }
      walletClient = yield primaryWallet.getWalletClient(String(chainId));
      if (!walletClient) {
        throw new Error(`primaryWallet.getWalletClient(${chainId}) returned undefined`);
      }
    } catch (error) {
      console.error("[CryptoWalletConnectionHandler] failed to get wallet client", error);
      iframeClient.send("crypto:send-transaction:failed", {
        error: error.message
      });
      return;
    }
    let parsedTransaction;
    try {
      parsedTransaction = parseTransaction(serializedTransaction);
    } catch (error) {
      console.error("[CryptoWalletConnectionHandler] failed to parse transaction", error);
      iframeClient.send("crypto:send-transaction:failed", {
        error: error.message
      });
      return;
    }
    try {
      const txId = yield walletClient.sendTransaction(parsedTransaction);
      console.log("[CryptoWalletConnectionHandler] txId", txId);
      iframeClient.send("crypto:send-transaction:success", {
        txId
      });
    } catch (error) {
      console.error("[CryptoWalletConnectionHandler] failed to send transaction", error);
      iframeClient.send("crypto:send-transaction:failed", {
        error: error.message
      });
    }
  });
}
export {
  handleEvmTransaction
};
//# sourceMappingURL=handleEvmTransaction.js.map