import { SignableMessage, Account, WalletClient, Transport, Chain } from 'viem';
import { IEmbeddedWalletSolanaSigner } from '@dynamic-labs/solana';

type EVMWalletClient = WalletClient<Transport, Chain, Account>;
type CustomEVMAdminSigner = EVMWalletClient & {
    type: "evm-keypair";
    address: `0x${string}`;
    signer: {
        type: "viem_v2";
        signMessage: (data: {
            message: SignableMessage;
        }) => Promise<`0x${string}`>;
        account: Account;
    };
};
type CustomSolanaAdminSigner = IEmbeddedWalletSolanaSigner & {
    type: "solana-keypair";
    address: string;
    signer: IEmbeddedWalletSolanaSigner;
};
declare function useDynamicConnect(isWeb3Enabled: boolean, setIsDynamicSdkLoaded: (sdkHasLoaded: boolean) => void, accessToken?: string): {
    sdkHasLoaded: boolean;
    getAdminSigner: () => Promise<CustomEVMAdminSigner | CustomSolanaAdminSigner | null>;
    cleanup: () => void;
    isDynamicWalletConnected: boolean;
};

export { type CustomEVMAdminSigner, type CustomSolanaAdminSigner, useDynamicConnect };
